<?php
/*
Plugin Name: Device Detect
Plugin URI: https://www.kleor.com/device-detect/
Description: Allows you to detect the device of the user, and to display some contents only for the phones, tablets or computers.
Version: 1.4.6
Author: Kleor
Author URI: https://www.kleor.com
Text Domain: device-detect
Domain Path: /languages
License: GPL2
*/

/* 
Copyright 2018 Kleor (https://www.kleor.com)

This program is a free software. You can redistribute it and/or 
modify it under the terms of the GNU General Public License as 
published by the Free Software Foundation, either version 2 of 
the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, 
but without any warranty, without even the implied warranty of 
merchantability or fitness for a particular purpose. See the 
GNU General Public License for more details.
*/


if (!defined('ABSPATH')) { exit(); }
define('DEVICE_DETECT_PATH', plugin_dir_path(__FILE__));
define('DEVICE_DETECT_URL', plugin_dir_url(__FILE__));
define('DEVICE_DETECT_FOLDER', substr(plugin_basename(__FILE__), 0, -strlen('/device-detect.php')));
if (!defined('DEVICE_DETECT_CUSTOM_FILES_PATH')) { define('DEVICE_DETECT_CUSTOM_FILES_PATH', substr(DEVICE_DETECT_PATH, 0, -(strlen(DEVICE_DETECT_FOLDER) + 1)).'device-detect-custom-files/'); }
define('DEVICE_DETECT_CUSTOM_FILES_URL', site_url().'/'.substr(DEVICE_DETECT_CUSTOM_FILES_PATH, strlen(ABSPATH)));
$plugin_data = get_file_data(__FILE__, array('Version' => 'Version'));
define('DEVICE_DETECT_VERSION', $plugin_data['Version']);
if (!defined('MOBILE_DETECT_VERSION')) { define('MOBILE_DETECT_VERSION', '2.8.41'); }

function device_detect_path($file) { return (file_exists(DEVICE_DETECT_CUSTOM_FILES_PATH.$file) ? DEVICE_DETECT_CUSTOM_FILES_PATH : DEVICE_DETECT_PATH).$file; }

function device_detect_url($file) { return (file_exists(DEVICE_DETECT_CUSTOM_FILES_PATH.$file) ? DEVICE_DETECT_CUSTOM_FILES_URL : DEVICE_DETECT_URL).$file; }

if (is_admin()) { include_once device_detect_path('admin.php'); }

$device_detected = device_detected();


function device_detected() {
@session_start();
$key = 'device_detected_'.$_SERVER['REMOTE_ADDR'];
if ((isset($_SESSION[$key])) && (in_array($_SESSION[$key], array('computer', 'phone', 'tablet')))) { $device = $_SESSION[$key]; }
else {
if (strstr($_SERVER['HTTP_USER_AGENT'], 'astar')) { $device = 'tablet'; }
else {
if (!class_exists('Mobile_Detect')) { include_once device_detect_path('libraries/mobile-detect.php'); }
$device_detect = new Mobile_Detect();
if (!$device_detect->isMobile()) { $device = 'computer'; }
elseif ($device_detect->isTablet()) { $device = 'tablet'; }
else { $device = 'phone'; } }
$_SESSION[$key] = $device; }
session_write_close();
return $device; }


function device_detect_computer_content($atts, $content) {
$content = explode('[other]', do_shortcode($content));
if (device_detect_is_computer()) { $n = 0; } else { $n = 1; }
if (!isset($content[$n])) { $content[$n] = ''; }
return $content[$n]; }


function device_detect_is_computer() { global $device_detected; return ($device_detected == 'computer'); }


function device_detect_is_mobile() { global $device_detected; return (in_array($device_detected, array('phone', 'tablet'))); }


function device_detect_is_phone() { global $device_detected; return ($device_detected == 'phone'); }


function device_detect_is_tablet() { global $device_detected; return ($device_detected == 'tablet'); }


function device_detect_mobile_content($atts, $content) {
$content = explode('[other]', do_shortcode($content));
if (device_detect_is_mobile()) { $n = 0; } else { $n = 1; }
if (!isset($content[$n])) { $content[$n] = ''; }
return $content[$n]; }


function device_detect_phone_content($atts, $content) {
$content = explode('[other]', do_shortcode($content));
if (device_detect_is_phone()) { $n = 0; } else { $n = 1; }
if (!isset($content[$n])) { $content[$n] = ''; }
return $content[$n]; }


function device_detect_tablet_content($atts, $content) {
$content = explode('[other]', do_shortcode($content));
if (device_detect_is_tablet()) { $n = 0; } else { $n = 1; }
if (!isset($content[$n])) { $content[$n] = ''; }
return $content[$n]; }


function load_device_detect_textdomain($domain = '') {
$domain = 'device-detect'.($domain == '' ? '' : '-'.$domain);
$file = $domain.'-'.apply_filters('plugin_locale', get_locale(), $domain).'.mo';
if (load_textdomain($domain, device_detect_path('languages/'.$file))) { return true; }
else { return load_textdomain($domain, WP_LANG_DIR.'/plugins/'.$file); } }


$tags = array();
foreach (array('computer', 'mobile', 'phone', 'tablet') as $string) {
for ($i = 0; $i < 4; $i++) { $tag = $string.'-content'.($i == 0 ? '' : $i); $tags[] = $tag; add_shortcode($tag, 'device_detect_'.$string.'_content'); } }
$device_detect_shortcodes = $tags;


add_filter('wp_is_mobile', 'device_detect_is_mobile');


foreach (array(
'get_the_excerpt',
'get_the_title',
'single_post_title',
'the_excerpt',
'the_excerpt_rss',
'the_title',
'the_title_attribute',
'the_title_rss',
'widget_text',
'widget_title') as $function) { add_filter($function, 'do_shortcode'); }